@@ -22,20 +22,6 @@ from Tea.model import TeaModel
 from Tea.converter import TeaConverter
 
 
-def prepare_headers(headers):
-    canon_keys = []
-    tmp_headers = {}
-    for k, v in headers.items():
-        if v is not None:
-            if k.lower() not in canon_keys:
-                canon_keys.append(k.lower())
-                tmp_headers[k.lower()] = [TeaConverter.to_string(v).strip()]
-            else:
-                tmp_headers[k.lower()].append(TeaConverter.to_string(v).strip())
-    canon_keys.sort()
-    return {key: ','.join(sorted(tmp_headers[key])) for key in canon_keys}
-
-
 def rsa_sign(plaintext, secret):
     if not secret.startswith('-----BEGIN RSA PRIVATE KEY-----'):
         secret = '-----BEGIN RSA PRIVATE KEY-----\n%s' % secret
@@ -422,7 +408,6 @@ class Client(object):
         canonical_uri = request.pathname if request.pathname else '/'
         canonicalized_query = get_canonical_query_string(request.query)
         canonicalized_headers, signed_headers = get_canonicalized_headers(request.headers)
-        request.headers = prepare_headers(request.headers)
 
         canonical_request = '%s\n%s\n%s\n%s\n%s\n%s' % (
             request.method,
